<?php

/*
Plugin Name: ArtistDataPress
Plugin URI: http://slushman.com/plugins/artistdatapress
Description: Display your ArtistData show feed on your WordPress site and customize how it appears.  ADP now uses the PHP functions cURL and SImpleXML to fetch and display your ArtistData XML feed.
Version: 0.371
Author: Slushman
Author URI: http://www.slushman.com
License: GPLv2

**************************************************************************

  Copyright (C) 2012 Slushman

  This program is free software: you can redistribute it and/or modify
  it under the terms of the GNU General License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General License for more details.

  You should have received a copy of the GNU General License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.

**************************************************************************
*/

if ( !class_exists( "ArtistDataPress_Plugin" ) ) { //Start Class

	class ArtistDataPress_Plugin {
	
		public static $instance;
	
		function __construct() {
		
			self::$instance = $this;
			
			// Runs when plugin is activated
			register_activation_hook( __FILE__, array( $this, 'create_options' ) ); 
			
			// Queues the included stylesheet
			wp_register_style( 'slushman-adp',  plugins_url( 'css/artistdatapress.css', __FILE__ ) );
			wp_register_style( 'slushman-adp-layout-default',  plugins_url( 'css/default.css', __FILE__ ) );
			wp_enqueue_style( 'slushman-adp' );
			
			// Adds the ArtistDataPress option menu to the Settings menu
			add_action( 'admin_menu', array( $this, 'add_menu' ) );
			
			//	Add "Settings" link to plugin page
			add_filter( 'plugin_action_links_' . plugin_basename( __FILE__ ) , array( $this, 'settings_link' ) );
			
			// Register and define the settings
			add_action( 'admin_init', array( $this, 'register_settings' ) );
		
			// Create shortcode [artistdatapress]
			add_shortcode( 'artistdatapress', array( $this, 'shortcode' ) );
			
			// Include other files
			add_action( 'init', array( $this, 'file_includer' ) );
		
		} // End of __construct()

		function create_options() {
		
			$options = array(
				'slushman_adp_xml_url' => '',
				'slushman_adp_adpage_url' => '',
				'slushman_adp_max_shows' => '',
				'slushman_adp_display_time' => '',
				'slushman_adp_display_tickets' => '',
				'slushman_adp_display_age' => '',
				'slushman_adp_display_country' => '',
				'slushman_adp_no_shows' => 'There are no shows currently scheduled.',
				'slushman_adp_layout' => '',
			);
			
			update_option( 'slushman_adp_options', $options );
			
		} // End of create_options()
		
// Options Page
		
		function add_menu() {
		
			add_options_page( 
				'ArtistDataPress Options', 
				'ArtistDataPress', 
				'manage_options', 
				'slushman-adp', 
				array( $this, 'options_page' ) 
			);
		
		} // End of add_menu()
		
		function settings_link( $links ) {
		
			$slushman_adp_settings_link = sprintf( '<a href="%s">%s</a>', admin_url( 'options-general.php?page=slushman-adp' ), __( 'Settings' ) );
		
			array_unshift( $links, $slushman_adp_settings_link );
		
			return $links;
		
		} // End of settings_link()
		
		function options_page() { ?>
			
			<div class="wrap">
			<div class="icon32" style="background-image:url(<?php echo plugins_url( 'images/artistdatapress-logo32x32.png', __FILE__ ); ?>); background-repeat:no-repeat;"><br /></div>
			<h2>ArtistDataPress Options</h2>
			
			<form method="post" action="options.php">
			<?php settings_fields( 'slushman_adp_settings' ); ?>
			<?php do_settings_sections( 'slushman-adp' ); ?>
			<br />
			<input class="button-primary" type="submit" name="Submit" value=" <?php _e( 'Save Options' ); ?> " />
			</form>
			
			<div id="slushman_paypal">
			
				
			
			</div>
			
			</div> <?php
		
		} // End of options_page()

		function register_settings() {
		
			register_setting( 'slushman_adp_settings', 'slushman_adp_options', array( $this, 'validate_options' ) );
			
			add_settings_section( 'slushman_adp_urls', 'ArtistData URLs', array( $this, 'url_section' ), 'slushman-adp' );
			add_settings_section( 'slushman_adp_display', 'ArtistData Display Options', array( $this, 'display_section' ), 'slushman-adp' );
			add_settings_section( 'slushman_adp_times', 'Times and Dates Display', array( $this, 'time_section' ), 'slushman-adp' );
			// add_settings_section( 'slushman_adp_styling', 'Choose the Styling', array( $this, 'styling_section' ), 'slushman-adp' );
			
			add_settings_field( 'slushman_adp_xml_url_field', 'ArtistData XML feed URL', array( $this, 'xml_url_field' ), 'slushman-adp', 'slushman_adp_urls' );
			add_settings_field( 'slushman_adp_adpage_url_field', 'ArtistData Profile URL', array( $this, 'adpage_url_field' ), 'slushman-adp', 'slushman_adp_urls' );
			add_settings_field( 'slushman_adp_max_shows_field', 'Display how many shows?', array( $this, 'max_shows_field' ), 'slushman-adp', 'slushman_adp_display' );
			add_settings_field( 'slushman_adp_display_name_field', 'Display show name?', array( $this, 'display_name_field' ), 'slushman-adp', 'slushman_adp_display' );
			add_settings_field( 'slushman_adp_display_tickets_field', 'Display ticket price?', array( $this, 'display_tickets_field' ), 'slushman-adp', 'slushman_adp_display' );
			add_settings_field( 'slushman_adp_display_age_field', 'Display age limits?', array( $this, 'display_age_field' ), 'slushman-adp', 'slushman_adp_display' );
			add_settings_field( 'slushman_adp_display_country_field', 'Display country?', array( $this, 'country_field' ), 'slushman-adp', 'slushman_adp_display' );
			add_settings_field( 'slushman_adp_no_shows_field', 'Customize your "No shows" message', array( $this, 'no_shows_field' ), 'slushman-adp', 'slushman_adp_display' );
			add_settings_field( 'slushman_adp_display_time_field', 'Display show time?', array( $this, 'display_time_field' ), 'slushman-adp', 'slushman_adp_times' );
			add_settings_field( 'slushman_adp_time_format_field', 'Time format:', array( $this, 'display_time_format_field' ), 'slushman-adp', 'slushman_adp_times' );
			add_settings_field( 'slushman_adp_date_format_field', 'Date format:', array( $this, 'display_date_format_field' ), 'slushman-adp', 'slushman_adp_times' );
			// add_settings_field( 'slushman_adp_styling_field', 'What styling do you prefer?', array( $this, 'styling_preference_field' ), 'slushman-adp', 'slushman_adp_styling' );
					
		} // End of register_settings()
		
		function url_section() {
		
			echo '<p>The ArtistData XML feed URL can be found on your ArtistData account by going to Tools > Data Feeds.</p>';
		
		}
		
		function display_section() {
		
			echo '<p>Choose what information you want displayed on your calendar.</p>';
		
		}
		
		function time_section() {
		
			echo '<p>Choose how you want to format your times and dates.</p>';
		
		}
		
		function styling_section() {
		
			echo '<p>Choose how you want the calendar to appear.</p>';
		
		} // End of styling_section_fn()
		
		function xml_url_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_xml_url" class="slushman_adp_options_field" name="slushman_adp_options[slushman_adp_xml_url]" type="text" value="<?php echo $options["slushman_adp_xml_url"]; ?>" /><?php
			
		}
		
		function adpage_url_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_adpage_url" class="slushman_adp_options_field" name="slushman_adp_options[slushman_adp_adpage_url]" type="text" value="<?php echo $options["slushman_adp_adpage_url"]; ?>" /><?php
			
		}
		
		function max_shows_field() {
		
			$options = get_option( 'slushman_adp_options' ); 
			
			if ( empty( $options["slushman_adp_max_shows"] ) ) {
			
				$max = 'All';
			
			} else {
			
				$max = $options["slushman_adp_max_shows"];
			
			} // End of $options empty checkdate ?>
			
			<input id="slushman_adp_max_shows" name="slushman_adp_options[slushman_adp_max_shows]" type="text" value="<?php echo $max; ?>" /><?php
		
		}
		
		function display_name_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_name" name="slushman_adp_options[slushman_adp_display_name]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_name'], 'on' ); ?> /><?php
		
		}
		
		function display_tickets_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_tickets" name="slushman_adp_options[slushman_adp_display_tickets]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_tickets'], 'on' ); ?> /><?php
		
		}
		
		function display_age_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_age" name="slushman_adp_options[slushman_adp_display_age]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_age'], 'on' ); ?> /><?php
		
		}
		
		function country_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_country" name="slushman_adp_options[slushman_adp_country]" type="checkbox" value="on" <?php checked( $options['slushman_adp_country'], 'on' ); ?> /><?php
		
		}
		
		function no_shows_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_no_shows" class="slushman_adp_options_field" name="slushman_adp_options[slushman_adp_no_shows]" type="text" value="<?php echo $options["slushman_adp_no_shows"]; ?>" /><?php
		
		}
		
		function display_time_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			<input id="slushman_adp_display_time" name="slushman_adp_options[slushman_adp_display_time]" type="checkbox" value="on" <?php checked( $options['slushman_adp_display_time'], 'on' ); ?> /><?php
		
		}
		
		function display_time_format_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			
			<select id="slushman_adp_time_format" name="slushman_adp_options[slushman_adp_time_format]">
				<option value="default">Default WordPress setting</option><?php
				
				$selections = array( 'g:i a', 'g:i A', 'H:i', 'h:i', 'G:i' );
				$today 		= time();
				
				foreach ( $selections as $selection ) { 
				
					$format = date( $selection, $today ); ?>
					<option value="<?php echo $selection; ?>"<?php selected( $options['slushman_adp_time_format'], $selection ); ?>><?php echo $format; ?></option><?php
					
				} // End of $selections foreach ?>
			</select><?php
		
		} // End of display_time_format_field()
		
		function display_date_format_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			
			<select id="slushman_adp_date_format" name="slushman_adp_options[slushman_adp_date_format]">
				<option value="default">Default WordPress setting</option><?php
				
				
				$selections = array( 'D n/d/Y', 'n/d/Y', 'F j, Y', 'Y/m/d', 'd/m/Y', 'm/d/Y', 'l, n/d/Y', 'M j, Y' );
				$today 		= time();
				
				foreach ( $selections as $selection ) { 
				
					$format = date( $selection, $today ); ?>
					<option value="<?php echo $selection; ?>"<?php selected( $options['slushman_adp_date_format'], $selection ); ?>><?php echo $format; ?></option><?php
					
				}  // End of $selections foreach ?>
			</select><?php
		
		} // End of display_date_format_field()
		
		function styling_preference_field() {
		
			$options = get_option( 'slushman_adp_options' ); ?>
			
			<select id="slushman_adp_styling" name="slushman_adp_options[slushman_adp_styling]"><?php
				
				$selections = array( 'Classic ADP', 'iCal ADP' );
				
				foreach ( $selections as $selection ) { ?>
				
					<option value="<?php echo $selection; ?>"<?php selected( $options['slushman_adp_styling'], $selection ); ?>><?php echo $selection; ?></option><?php
					
				} // End of $selections foreach ?>
			</select><?php
		
		} // End of styling_preference()
				
		function validate_options( $input ) {
		
			$input['slushman_adp_xml_url'] 		= esc_url_raw( $input['slushman_adp_xml_url'] );
			$input['slushman_adp_adpage_url'] 	= esc_url( $input['slushman_adp_adpage_url'] );
			$input['slushman_adp_max_shows'] 	= intval( $input['slushman_adp_max_shows'] );
			
			return $input;
		
		} // End of validate_options()

/**
 * Processes and outputs the raw ArtistData XML feed
 *
 * get_xml() gets the value of the slushman_adp_xml_url plugin option,
 * then fetches the ArtistData XML file at that URL. It then parses
 * the XML into an array, which can be displayed easily.
 * 
 * Here's wheere the cURL code came from:
 * http://www.bobulous.org.uk/coding/php-5-xml-feeds.html
 *
 * @since 0.3
 *
 * @uses get_option
 * @uses cURL
 * @uses SimpleXmlElement
 *
 * @return array Data from the ArtistData XML
 */
		function get_xml() {
		
			$options = get_option( 'slushman_adp_options' );
			
			if ( !empty( $options['slushman_adp_xml_url'] ) ) {
			
				$xml_url = curl_init( $options['slushman_adp_xml_url'] );
				
				curl_setopt( $xml_url, CURLOPT_RETURNTRANSFER, true );
				curl_setopt( $xml_url, CURLOPT_CONNECTTIMEOUT, 4 );
				curl_setopt( $xml_url, CURLOPT_AUTOREFERER, TRUE );
				curl_setopt( $xml_url, CURLOPT_MAXREDIRS, 10 );
				curl_setopt( $xml_url, CURLOPT_FOLLOWLOCATION, TRUE );
				$xml = curl_exec( $xml_url );

				curl_close( $xml_url );
				
				libxml_use_internal_errors( true );
			    
			    try {
			    
			        $data = new SimpleXMLElement( $xml );
			    
			    } catch ( Exception $e ) {
			    
			        $error_message = 'SimpleXMLElement threw an exception.';
			    
			        foreach( libxml_get_errors() as $error_line ) {
			    
			            $error_message .= "\t" . $error_line->message;
			    
			        } // End of libxml_get_errors foreach
			    
			        trigger_error( $error_message );
			        
			        $error = array( 'Error', 'There seems to be a problem with your feed URL.' );
					return $error;
			    
			    } // End of try / catch
			    
			    if ( $data != FALSE ) {
				
					$key = $data->show[0]->recordKey;
				
					if ( !empty( $key ) ) {
				
						return $data;
					
					} else {

						return FALSE;
					
					} // End of $key empty check
			
				} // End of $data check
				
			} else {
			
				$error = array( 'Error', 'Please enter a feed in the options page.' );
				return $error;
			
			} // End of slushman_adp_xml_url empty check

		} // End of get_xml()
		
/**
 * Display errors and notices
 *
 * 
 *
 * @since 0.2
 *
 * @param array $args Array of data
 *
 * @return mixed HTML formatted error message
 */
 		function display_errors_and_notices( $args ) {
 		
 			$notices = array(
 				'check_field' 	=> sprintf( __( '<div id="message" class="error"><p>The %s field is either invalid or empty.</p></div>' ), $args['field'] ),
 				'already_used' 	=> sprintf( __( '<div id="message" class="error"><p>This %s is already used by another user.</p></div>' ), $args['used'] ),
 				'not_set' 		=> sprintf( __( '<div id="message" class="error"><p>The %s is not set.</p></div>' ), $args['unset'] ),
 				'fail' 			=> sprintf( __( '<div id="message" class="error"><p>Could not %s the %s.</p></div>' ), $args['failure'], $args['failed'] ),
 				'success' 		=> sprintf( __( '<div id="message" class="updated"><p>%s %s successfully.</p></div>' ), $args['succeeded'], $args['successful'] ),
 				'attended' 		=> sprintf( __( '<div id="message" class="error"><p>%s has already received credit for this seminar.</p></div>' ), $args['student_name'] ),
 				'enrolled'		=> sprintf( __( '<div id="message" class="updated"><p>%s has been marked as enrolled.</p></div>' ), $args['student_name'] ),
 				'unregistered' 	=> __( '<div id="message" class="error"><p>This student is not currently registered for the seminar course.</p></div>' ),
 				'errors' 		=> sprintf( __( '<div id="message" class="error"><p>%s</p></div>' ), $args['error'] ),
 				'attendance'	=> sprintf( __( '<div id="message" class="updated"><p>Attendance at %s for %s was added successfully.</p></div>' ), $args['event'], $args['student'] ),
 				'partial'		=> sprintf( __( '<div id="message" class="error"><p>%s updated, but %s did not.</p></div>' ), $args['updated'], $args['same'] ),
  			);
 			
 			$notice = $notices[$args['which']];
 			return $notice;
 		
 		} // End of display_errors_and_notices()		
		
// Create shortcode [artistdatapress]
		function shortcode( $atts ) {
		
			ob_start();
			
			$options 		= get_option( 'slushman_adp_options' );
			$layout_option 	= $options['slushman_adp_layout'];
			$layout 		= new Layout;
			
			$layout->get_layout( $layout_option );
			
			$output = ob_get_contents();
			
			ob_end_clean();
			
			return $output;
		
		} // End of shortcode()
		
		
/**
 * Include other files
 *
 * Includes all files containing functions outside the class.
 *
 * @since 0.37
 */
		function file_includer() {
	
			require( 'inc/layout.php' );
	
		} // End of file_includer()		

	} // End of ArtistDataPress_Plugin

} // End of class check

require_once( dirname( __FILE__ ) . '/inc/adp_widget.php' );

new ArtistDataPress_Plugin;

?>