<?php

if ( !class_exists( "Layout" ) ) {

	class Layout extends ArtistDataPress_Plugin {
	
		public static $instance;
	
		function __construct() {
		
			self::$instance = $this;
			
		} // End of __construct()

/**
 * Displays the user's chosen layout
 *
 * Gets the options, then registers and enqueues the correct CSS and calls the correct function to 
 * display that layout's HTML.
 *
 * @since 0.4
 *
 *
 * @params string $layout The option name of the user's preferred layout
 *
 * @uses wp_register_style
 * @uses plugins_url
 * @uses wp_enqueue_style
 * @uses default_layout
 */	
		function get_layout( $layout ) {
		
			switch ( $layout ) {
			
				
				/*case '' :
				
					break;
				*/
				default :	
					wp_register_style( 'slushman-adp',  plugins_url( 'css/artistdatapress.css', dirname( __FILE__ ) ) );
					wp_enqueue_style( 'slushman-adp' );
					$this->default_layout();
					break;
			
			} // End of $layout switch
			
		} // End of get_layout()

/**
 * Displays the ArtistData XML feed for use on a page
 *
 * artistdatapress() gets all the plugins options, gets the XML data as an array,
 * then outputs an HTML table based on the user-selected options.
 *
 * @since 0.4
 *
 * @return mixed $output HTML-formatted table showing upcoming shows from an ArtistData feed
 */	
		function default_layout() {
		
			$options 	= get_option( 'slushman_adp_options' );
			$showfeed 	= $this->get_xml();
			
			extract( $options ); ?>
			
			<div id="slushman_adp"><?php
			
			if ( $showfeed == FALSE ) { ?>
			
				<div id="slushman_adp_no_shows"><?php echo $slushman_adp_no_shows; ?></div><?php
				
			} elseif ( $showfeed !== FALSE && is_array( $showfeed ) && $showfeed[0] == 'Error' ) { ?>
			
				<div id="slushman_adp_display_messages"><?php echo $showfeed[1]; ?></div><?php
			
			} elseif ( $showfeed !== FALSE && !is_array( $showfeed ) ) {
			
				// This is for limiting how many shows are displayed.
				$count = 0;
						
			    foreach ( $showfeed->show as $show ) { 
			    
			    	// Date
			    	if ( $slushman_adp_date_format == 'default' ) {
							
						$date_format = get_option( 'date_format' );
						
					} else {
					
						$date_format = $slushman_adp_date_format;
					
					} // End of $slushman_adp_date_format check
			    	
			    	$showdate	= strtotime( $show->date );
					$date		= date( $date_format, $showdate );
			    	
			    	
			    	
			    	// Time
			    	if ( $slushman_adp_time_format == 'default' ) {
								
						$time_format = get_option( 'time_format' );
						
					} else {
					
						$time_format = $slushman_adp_time_format;
					
					} // End of $slushman_adp_time_format check
					
					$showtime 	= strtotime( $show->timeSet );
					$time 		= date( $time_format, $showtime );
					
					
					
					// ISO
					$convert 	= new DateTime( $show->date . ' ' . $show->timeSet, new DateTimeZone( $show->showtimeZone ) );
					$iso 		= $convert->format( 'Y-m-d\TH:i:sP' );
		
					
										
					// Venue
					// Make the venue name a link to their site, else display venue name
					if ( $show->venueURI && $show->venueURI != '' ) {
				
						$venue = '<a class="slushman_adp_venue_link" href="' . $show->venueURI . '" itemprop="name">' . $show->venueName . '</a>';
						
					} else {
					
						$venue = '<span class="slushman_adp_venue_link" itemprop="name">' . $show->venueName . '</span>';
					
					} // End of $show->venueURI empty check
					
					
					
					// Location
					if ( $show->stateAbbreviation == 'No State' ) {
							
						$loc = '<span itemprop="locality">' . $show->city . '</span>, <span itemprop="country-name">' . $show->country . '</span>';
					
					} elseif ( $slushman_adp_country == 'on' ) {
					
						$loc = '<span itemprop="locality">' . $show->city . '</span>, <span itemprop="region">' . $show->stateAbbreviation . '</span>, <span itemprop="country-name">' . $show->countryAbbreviation . '</span>';
					
					} else {
					
						$loc = '<span itemprop="locality">' . $show->city . '</span>, <span itemprop="region">' . $show->stateAbbreviation . '</span>';
					
					} // End of stateAbbreviation check
					
					
					
					// Make the city & state a Google Map link, else just show city & state
					if ( $show->venueAddress && $show->venueAddress != '' ) {
					
						// $latitude = ;
						// $longitude = ;
					
						$location = '<a class="slushman_adp_venue_map" href="http://maps.google.com/maps?q=' . $show->venueAddress . '+' . $show->city . '+' . $show->stateAbbreviation . '+' . $show->country . '"><span class="slushman_adp_venue_location">' . $loc . '</span><span class="slushman_adp_map_notice"> - map</span></a>
						
						<span itemprop="geo" itemscope itemtype="http://data-vocabulary.org/?Geo">
					        <meta itemprop="latitude" content="' . $latitude . '" />
					        <meta itemprop="longitude" content="' . $longitude . '" />
					    </span>';
					    
					} else {
					
						$location = '<span class="slushman_adp_show_no_map">' . $loc . '</span>';
						
					} // End of if ( !empty( $show->venueAddress ) )
			    	
			    	?>
			    	
					<div class="slushman_adp_shows" id="slushman_adp_<?php echo $show->recordKey; ?>" itemscope itemtype="http://data-vocabulary.org/Event">
							
						<div class="slushman_adp_date_time slushman_adp_header_row" itemprop="startDate" datetime="<?php echo $iso; ?>">										
							<span class="slushman_adp_show_date"><?php echo $date; ?></span><?php
							
							// Display the show time if selected in the plugin options
							if ( $slushman_adp_display_time == 'on' && isset( $slushman_adp_time_format ) ) { ?>
								
								<span class="slushman_adp_show_time"> at <?php echo $time; ?></span><?php
							
							} // End of $slushman_adp_display_time check ?>
						
						</div><!-- End of slushman_adp_date_time -->
						
						<div class="slushman_adp_venue slushman_adp_header_row" itemprop="location" itemscope itemtype="http://data-vocabulary.org/?Organization">
							<?php echo $venue; ?>
						</div><!-- End of slushman_adp_venue -->
						
						<div class="slushman_adp_show_location slushman_adp_header_row" itemprop="address" itemscope itemtype="http://data-vocabulary.org/Address">
							<?php echo $location; ?>
						</div><!-- End of slushman_adp_show_location --><?php
				
						// Display the show name if selected in the plugin options
						if ( $slushman_adp_display_name == 'on') { ?>
										
							<div class="slushman_adp_show_name" itemprop="summary"><?php echo $show->name; ?></div><?php
												
						} // End of if ( $slushman_adp_display_name == 'on') ?>
						
							<div class="slushman_adp_show_details" itemprop="tickets" itemscope itemtype="http://data-vocabulary.org/Offer"><?php
									
							// Display the ticket price if selected in the plugin options
							if ( $slushman_adp_display_tickets == 'on') {
							
								// Make the ticket price into a link, otherwise just show the price
								if ( $show->ticketURI && $show->ticketURI != '' ) { ?>
					
									<a class="slushman_adp_show_price" href="<?php echo $show->ticketURI; ?>" itemprop="offerurl">Tickets: <span itemprop="price"><?php echo $show->ticketPrice; ?></span></a><?php
										
								} else { ?>
								
									<span class="slushman_adp_show_price">Tickets: <?php echo $show->ticketPrice; ?></span><?php
									
								} // End of $show->ticketURI empty check
							
							} // End of $slushman_adp_display_tickets check
							
							// Display the age limit if selected in the plugin options
							if ( $slushman_adp_display_age == 'on') { ?>
					
								<span class="slushman_adp_show_age" itemprop="description">Age Limit: <?php echo $show->ageLimit; ?></span><?php
								
							} // End of $slushman_adp_display_age check ?>
						
						</div><!-- End of slushman_adp_show_details -->
						
						<div class="slushman_adp_spacer_row">&nbsp;</div>
								
					</div><!-- End of slushman_adp_shows --><?php
						
					++$count;
				
					if ( $count == $slushman_adp_max_shows ) { 
					
						break; //Stop after the count has reached $slushman_adp_max_shows
						
					} // End of $slushman_adp_max_shows check
				
				} // End of $showfeed foreach
				
			} // End of $showfeed empty check ?>
		
				<div id="slushman_adp_more_shows" class="slushman_adp_footer"><?php
					
					if ( !empty( $slushman_adp_max_shows ) ) { ?>
					
						<span id="slushman_adp_more"><a href="<?php echo $slushman_adp_adpage_url; ?>">More shows</a></span><?php
						
					} //End of $slushman_adp_max_shows empty check ?>
				
				</div><!-- End of slushman_adp_more_shows -->
				
				<div id="slushman_adp_artistdata_link" class="slushman_adp_footer">&nbsp;
				
					<a id="slushman_adp_artistdata_logo_link" href="http://artistdata.com" target="_blank">
			    		<img border="0" id="slushman_adp_artistdata_logo" src="<?php echo plugins_url( 'images/powered_by_artistdata.png', dirname( __FILE__ ) ); ?>">
			    	</a>
				
				</div><!-- End of slushman_adp_artistdata_logo_link -->
			
			</div><!-- End of slushman_adp --><?php
		
		} // End of default_layout()
		
	} // End of Layout class
	
} // End of class_exists check

?>